<?php

namespace App\Form\DataTransformer;

use Symfony\Component\Form\DataTransformerInterface;
use Symfony\Component\Form\Exception\TransformationFailedException;

class MinutesToPeriodTransformer implements DataTransformerInterface
{
    /**
     * Transforms a string (period) to an int
     * 
     * @param string|null $period
     */
    public function transform($period): int
    {
        if (null === $period) {
            return 0;
        }

        return (int) filter_var($period, FILTER_SANITIZE_NUMBER_INT) ?? 0;
    }

    /**
     * Transforms a string (number) to an object (issue).
     *
     * @param  int $minutes
     * @throws TransformationFailedException if object (issue) is not found.
     */
    public function reverseTransform($minutes): ?string
    {
        // no issue number? It's optional, so that's ok
        if (!$minutes) {
            $minutes = 0;
        }

        return 'PT' . $minutes . 'M';
    }
}